@@ -26,16 +26,13 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
-
 #include <string.h>
+
 #include <glib.h>
 #include <glib/gstdio.h>
+#include <glib/gi18n-lib.h>
 
-#include "gnome-i18nP.h"
-
-#include "gnome-program.h"
 #include "gnome-url.h"
-
 #include "gnome-help.h"
 
 static char *
@@ -149,7 +146,7 @@ gnome_help_display_with_doc_id_and_env (GnomeProgram  *program,
 
 	if (doc_id == NULL) {
 		g_object_get (program, GNOME_PARAM_APP_ID, &doc_id, NULL);
-		free_doc_id = doc_id;
+		free_doc_id = (char *)doc_id;
 	}
 
 	if (doc_id == NULL)
@@ -217,7 +214,7 @@ gnome_help_display_with_doc_id_and_env (GnomeProgram  *program,
 			g_set_error (error,
 				     GNOME_HELP_ERROR,
 				     GNOME_HELP_ERROR_NOT_FOUND,
-				     _("Unable to find help paths %s or %s."
+				     _("Unable to find help paths %s or %s. "
 				       "Please check your installation"),
 				     local_help_path,
 				     global_help_path);
